==> qtjambi-pdf-debuginfo-linux-x64-6.5.3.jar: sources/QtJambiPdf/QPdfSelection_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtPdf/qpdfselection.h>
#include <QtCore/QVariant>
#include <QtCore/QList>
#include <QtGui/qpolygon.h>
#include <QtCore/qrect.h>
#include <QtGui/qclipboard.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambiGui/hashes.h>
#include <QtJambiPdf/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QPdfSelection(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QPdfSelection")
    QPdfSelection *_ptr = reinterpret_cast<QPdfSelection *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QPdfSelection(QPdfSelection)
void __qt_construct_QPdfSelection_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPdfSelection(QPdfSelection)")
    jobject other0 = __java_arguments[0].l;
    const QPdfSelection& __qt_other0 = qtjambi_cast<const QPdfSelection& >(__jni_env, other0);
    QPdfSelection *__qt_this = new(__qtjambi_ptr) QPdfSelection(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QPdfSelection
void __qt_destruct_QPdfSelection(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QPdfSelection")
    reinterpret_cast<QPdfSelection*>(ptr)->~QPdfSelection();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QPdfSelection::QPdfSelection(QPdfSelection)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_pdf_QPdfSelection_initialize_1native__Lio_qt_pdf_QPdfSelection_2Lio_qt_pdf_QPdfSelection_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPdfSelection::QPdfSelection(QPdfSelection)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPdfSelection_0, sizeof(QPdfSelection), typeid(QPdfSelection), false, &deleter_QPdfSelection, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPdfSelection::boundingRectangle()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_pdf_QPdfSelection_boundingRectangle_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QPdfSelection *__qt_this = QtJambiAPI::objectFromNativeId<QPdfSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPdfSelection::boundingRectangle()const", __qt_this)
        QRectF __qt_return_value = __qt_this->boundingRectangle();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPdfSelection::bounds()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_pdf_QPdfSelection_bounds_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QPdfSelection *__qt_this = QtJambiAPI::objectFromNativeId<QPdfSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPdfSelection::bounds()const", __qt_this)
        QList<QPolygonF> __qt_return_value = __qt_this->bounds();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPdfSelection::copyToClipboard(QClipboard::Mode)const
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_pdf_QPdfSelection_copyToClipboard_1native_1QClipboard_1Mode_1constfct__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint mode0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        const QPdfSelection *__qt_this = QtJambiAPI::objectFromNativeId<QPdfSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPdfSelection::copyToClipboard(QClipboard::Mode)const", __qt_this)
        QClipboard::Mode __qt_mode0 = qtjambi_cast<QClipboard::Mode>(__jni_env, mode0);
        __qt_this->copyToClipboard(QClipboard::Mode(__qt_mode0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPdfSelection::endIndex()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_pdf_QPdfSelection_endIndex_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QPdfSelection *__qt_this = QtJambiAPI::objectFromNativeId<QPdfSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPdfSelection::endIndex()const", __qt_this)
        __java_return_value = __qt_this->endIndex();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPdfSelection::isValid()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_pdf_QPdfSelection_isValid_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QPdfSelection *__qt_this = QtJambiAPI::objectFromNativeId<QPdfSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPdfSelection::isValid()const", __qt_this)
        __java_return_value = __qt_this->isValid();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPdfSelection::operator=(QPdfSelection)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_pdf_QPdfSelection_assign_1native_1cref_1QPdfSelection__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPdfSelection *__qt_this = QtJambiAPI::objectFromNativeId<QPdfSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPdfSelection::operator=(QPdfSelection)", __qt_this)
        const QPdfSelection& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QPdfSelection>(__jni_env, other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPdfSelection::operator==(QPdfSelection,QPdfSelection)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_pdf_QPdfSelection_operator_1equal_1native_1cref_1QPdfSelection__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID value21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QPdfSelection *__qt_this = QtJambiAPI::objectFromNativeId<QPdfSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPdfSelection::operator==(QPdfSelection,QPdfSelection)", __qt_this)
        const QPdfSelection& __qt_value21 = QtJambiAPI::objectReferenceFromNativeId<QPdfSelection>(__jni_env, value21);
        __java_return_value = (*__qt_this) == __qt_value21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPdfSelection::startIndex()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_pdf_QPdfSelection_startIndex_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QPdfSelection *__qt_this = QtJambiAPI::objectFromNativeId<QPdfSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPdfSelection::startIndex()const", __qt_this)
        __java_return_value = __qt_this->startIndex();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPdfSelection::swap(QPdfSelection&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_pdf_QPdfSelection_swap_1native_1ref_1QPdfSelection__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPdfSelection *__qt_this = QtJambiAPI::objectFromNativeId<QPdfSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPdfSelection::swap(QPdfSelection&)", __qt_this)
        QPdfSelection& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QPdfSelection>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPdfSelection::text()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_pdf_QPdfSelection_text_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QPdfSelection *__qt_this = QtJambiAPI::objectFromNativeId<QPdfSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPdfSelection::text()const", __qt_this)
        QString __qt_return_value = __qt_this->text();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_pdf_QPdfSelection_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QPdfSelection *__qt_this = QtJambiAPI::objectFromNativeId<QPdfSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_pdf_QPdfSelection_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QPdfSelection *__qt_this = QtJambiAPI::objectFromNativeId<QPdfSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QPdfSelection(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QPdfSelection(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QPdfSelection>("QPdfSelection", "io/qt/pdf/QPdfSelection");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QPdfSelection, {
        ConstructorInfo(&__qt_construct_QPdfSelection_0, "Lio/qt/pdf/QPdfSelection;")
    });
// END: function table

    registerMetaObject(typeId, QPdfSelection::staticMetaObject, false);
// END: signal table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QPdfSelection);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-pdf-debuginfo-linux-x64-6.5.4.jar: sources/QtJambiPdf/QPdfSelection_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtPdf/qpdfselection.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qrect.h>
#include <QtGui/qclipboard.h>
#include <QtGui/qpolygon.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambiGui/hashes.h>
#include <QtJambiPdf/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QPdfSelection(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QPdfSelection")
    QPdfSelection *_ptr = reinterpret_cast<QPdfSelection *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QPdfSelection(QPdfSelection)
void __qt_construct_QPdfSelection_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPdfSelection(QPdfSelection)")
    jobject other0 = __java_arguments[0].l;
    const QPdfSelection& __qt_other0 = qtjambi_cast<const QPdfSelection& >(__jni_env, other0);
    QPdfSelection *__qt_this = new(__qtjambi_ptr) QPdfSelection(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QPdfSelection
void __qt_destruct_QPdfSelection(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QPdfSelection")
    reinterpret_cast<QPdfSelection*>(ptr)->~QPdfSelection();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QPdfSelection::QPdfSelection(QPdfSelection)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_pdf_QPdfSelection_initialize_1native__Lio_qt_pdf_QPdfSelection_2Lio_qt_pdf_QPdfSelection_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPdfSelection::QPdfSelection(QPdfSelection)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPdfSelection_0, sizeof(QPdfSelection), typeid(QPdfSelection), false, &deleter_QPdfSelection, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPdfSelection::boundingRectangle()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_pdf_QPdfSelection_boundingRectangle_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QPdfSelection *__qt_this = QtJambiAPI::objectFromNativeId<QPdfSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPdfSelection::boundingRectangle()const", __qt_this)
        QRectF __qt_return_value = __qt_this->boundingRectangle();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPdfSelection::bounds()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_pdf_QPdfSelection_bounds_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QPdfSelection *__qt_this = QtJambiAPI::objectFromNativeId<QPdfSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPdfSelection::bounds()const", __qt_this)
        QList<QPolygonF> __qt_return_value = __qt_this->bounds();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPdfSelection::copyToClipboard(QClipboard::Mode)const
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_pdf_QPdfSelection_copyToClipboard_1native_1QClipboard_1Mode_1constfct__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint mode0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        const QPdfSelection *__qt_this = QtJambiAPI::objectFromNativeId<QPdfSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPdfSelection::copyToClipboard(QClipboard::Mode)const", __qt_this)
        QClipboard::Mode __qt_mode0 = qtjambi_cast<QClipboard::Mode>(__jni_env, mode0);
        __qt_this->copyToClipboard(QClipboard::Mode(__qt_mode0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPdfSelection::endIndex()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_pdf_QPdfSelection_endIndex_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QPdfSelection *__qt_this = QtJambiAPI::objectFromNativeId<QPdfSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPdfSelection::endIndex()const", __qt_this)
        __java_return_value = __qt_this->endIndex();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPdfSelection::isValid()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_pdf_QPdfSelection_isValid_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QPdfSelection *__qt_this = QtJambiAPI::objectFromNativeId<QPdfSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPdfSelection::isValid()const", __qt_this)
        __java_return_value = __qt_this->isValid();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPdfSelection::operator=(QPdfSelection)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_pdf_QPdfSelection_assign_1native_1cref_1QPdfSelection__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPdfSelection *__qt_this = QtJambiAPI::objectFromNativeId<QPdfSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPdfSelection::operator=(QPdfSelection)", __qt_this)
        const QPdfSelection& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QPdfSelection>(__jni_env, other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPdfSelection::operator==(QPdfSelection,QPdfSelection)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_pdf_QPdfSelection_equals_1native_1cref_1QPdfSelection__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID value21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QPdfSelection *__qt_this = QtJambiAPI::objectFromNativeId<QPdfSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPdfSelection::operator==(QPdfSelection,QPdfSelection)", __qt_this)
        const QPdfSelection& __qt_value21 = QtJambiAPI::objectReferenceFromNativeId<QPdfSelection>(__jni_env, value21);
        __java_return_value = (*__qt_this) == __qt_value21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPdfSelection::startIndex()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_pdf_QPdfSelection_startIndex_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QPdfSelection *__qt_this = QtJambiAPI::objectFromNativeId<QPdfSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPdfSelection::startIndex()const", __qt_this)
        __java_return_value = __qt_this->startIndex();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPdfSelection::swap(QPdfSelection&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_pdf_QPdfSelection_swap_1native_1ref_1QPdfSelection__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPdfSelection *__qt_this = QtJambiAPI::objectFromNativeId<QPdfSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPdfSelection::swap(QPdfSelection&)", __qt_this)
        QPdfSelection& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QPdfSelection>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPdfSelection::text()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_pdf_QPdfSelection_text_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QPdfSelection *__qt_this = QtJambiAPI::objectFromNativeId<QPdfSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPdfSelection::text()const", __qt_this)
        QString __qt_return_value = __qt_this->text();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_pdf_QPdfSelection_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QPdfSelection *__qt_this = QtJambiAPI::objectFromNativeId<QPdfSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_pdf_QPdfSelection_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QPdfSelection *__qt_this = QtJambiAPI::objectFromNativeId<QPdfSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QPdfSelection(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QPdfSelection(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QPdfSelection>("QPdfSelection", "io/qt/pdf/QPdfSelection");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QPdfSelection, {
        ConstructorInfo(&__qt_construct_QPdfSelection_0, "Lio/qt/pdf/QPdfSelection;")
    });
// END: function table

    registerMetaObject(typeId, QPdfSelection::staticMetaObject, false);
// END: signal table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QPdfSelection);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
